@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -22,7 +25,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-sns-notify", "0.0.543", __name__[0:-6], "cdk-sns-notify@0.0.543.jsii.tgz"
+    "cdk-sns-notify", "0.0.872", __name__[0:-6], "cdk-sns-notify@0.0.872.jsii.tgz"
 )
 
 __all__ = [
